# Django Userena

Userena is a Django application that supplies your Django project with full
account management. It's a fully customizable application that takes care of
the signup, activation, messaging and more. It's BSD licensed, which means you
can use it commercially for free!

## [Documentation](http://docs.django-userena.org/en/latest/index.html)

Complete documentation about the
[installation](http://docs.django-userena.org/en/latest/installation.html),
[settings](http://docs.django-userena.org/en/latest/settings.html) and
[F.A.Q.](http://docs.django-userena.org/en/latest/faq.html) is available on
[Read the Docs](http://docs.django-userena.org/en/latest/index.html).

## [Demo](http://django-userena.org/)

Want to test userena first, you can do just that at [django-userena.org](http://django-userena.org/).
